@@ -117,7 +117,7 @@ class CommonOperationsMixin:
         """Create the image list."""
 
         self.images = wx.ImageList(16, 16)
-        self.tint = data.RGBA(self.GetForegroundColour().Get())
+        self.tint = data.RGBA(self.GetForegroundColour().Get()[:3])
         self.doc = self.images.Add(data.get_bitmap('doc.png'))
         self.bin = self.images.Add(data.get_bitmap('binary.png'))
         self.sort_up = self.images.Add(data.get_bitmap('arrow_up.png', tint=self.tint, alpha=0.3))
