@@ -91,8 +91,8 @@ REGEX_MODE = 2
 BREGEX_MODE = 3
 
 SEARCH_MASK = 0x1FFFF
-FILE_MASK = 0x7FFFFE0000
-FNMATCH_FLAGS = 0x3F00000000
+FILE_MASK = 0xFFFFFE0000
+FNMATCH_FLAGS = 0xFF00000000
 
 RE_MODES = (RE_MODE, BRE_MODE)
 REGEX_MODES = (REGEX_MODE, BREGEX_MODE)
